Auto-generated docs-only module listing all defined dispatchables for this pallet. Note that members of this module cannot be used directly and are only provided for documentation purposes.

Functions

  • Execute an overweight message.
  • Remove a page which has no more messages remaining to be processed or is stale.