Function pallet_message_queue::pallet::dispatchables::execute_overweight
source · pub fn execute_overweight<T: Config>(
message_origin: MessageOriginOf<T>,
page: u32,
index: T::Size,
weight_limit: Weight
)Expand description
Execute an overweight message.
Temporary processing errors will be propagated whereas permanent errors are treated as success condition.
origin: Must beSigned.message_origin: The origin from which the message to be executed arrived.page: The page in the queue in which the message to be executed is sitting.index: The index into the queue of the message to be executed.weight_limit: The maximum amount of weight allowed to be consumed in the execution of the message.
Benchmark complexity considerations: O(index + weight_limit).
NOTE: This function is an automatically generated, doc only, uncallable stub.
designed to document the execute_overweight variant of
the pallet Call enum. You should not attempt to call this function
directly.