Struct pallet_message_queue::pallet::Pallet
source · pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
sourcepub fn reap_page(
origin: OriginFor<T>,
message_origin: MessageOriginOf<T>,
page_index: u32
) -> DispatchResult
pub fn reap_page( origin: OriginFor<T>, message_origin: MessageOriginOf<T>, page_index: u32 ) -> DispatchResult
Remove a page which has no more messages remaining to be processed or is stale.
sourcepub fn execute_overweight(
origin: OriginFor<T>,
message_origin: MessageOriginOf<T>,
page: u32,
index: T::Size,
weight_limit: Weight
) -> DispatchResultWithPostInfo
pub fn execute_overweight( origin: OriginFor<T>, message_origin: MessageOriginOf<T>, page: u32, index: T::Size, weight_limit: Weight ) -> DispatchResultWithPostInfo
Execute an overweight message.
Temporary processing errors will be propagated whereas permanent errors are treated as success condition.
origin: Must beSigned.message_origin: The origin from which the message to be executed arrived.page: The page in the queue in which the message to be executed is sitting.index: The index into the queue of the message to be executed.weight_limit: The maximum amount of weight allowed to be consumed in the execution of the message.
Benchmark complexity considerations: O(index + weight_limit).
sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
sourcepub fn do_execute_overweight(
origin: MessageOriginOf<T>,
page_index: u32,
index: T::Size,
weight_limit: Weight
) -> Result<Weight, Error<T>>
pub fn do_execute_overweight( origin: MessageOriginOf<T>, page_index: u32, index: T::Size, weight_limit: Weight ) -> Result<Weight, Error<T>>
Try to execute a single message that was marked as overweight.
The weight_limit is the weight that can be consumed to execute the message. The base
weight of the function it self must be measured by the caller.
sourcepub fn debug_info() -> String
pub fn debug_info() -> String
Print the pages in each queue and the messages in each page.
Processed messages are prefixed with a * and the current beginning page with a >.
Example output
queue Here:
page 0: []
> page 1: []
page 2: ["\0weight=4", "\0c", ]
page 3: ["\0bigbig 1", ]
page 4: ["\0bigbig 2", ]
page 5: ["\0bigbig 3", ]