pub trait ForceSetHead<O> {
// Required method
fn force_set_head(weight: &mut WeightMeter, origin: &O) -> Result<bool, ()>;
}Expand description
Allows to force the processing head to a specific queue.
Required Methods
Sourcefn force_set_head(weight: &mut WeightMeter, origin: &O) -> Result<bool, ()>
fn force_set_head(weight: &mut WeightMeter, origin: &O) -> Result<bool, ()>
Set the ServiceHead to origin.
This function:
Err: Queue did not exist, not enough weight or other error.Ok(true): The service head was updated.Ok(false): The service head was not updated since the queue is empty.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".