Type Alias pallet_message_queue::BookStateOf
source · pub type BookStateOf<T> = BookState<MessageOriginOf<T>>;Expand description
The BookState of this pallet.
Aliased Type
struct BookStateOf<T> { /* private fields */ }Trait Implementations
sourceimpl<MessageOrigin> Decode for BookState<MessageOrigin>where
Option<Neighbours<MessageOrigin>>: Decode,
impl<MessageOrigin> Decode for BookState<MessageOrigin>where Option<Neighbours<MessageOrigin>>: Decode,
sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy ) -> Result<Self, Error>
Attempt to deserialise the value from input.
sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>( input: &mut I, dst: &mut MaybeUninit<Self> ) -> Result<DecodeFinished, Error>where I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
sourceimpl<MessageOrigin> Encode for BookState<MessageOrigin>where
Option<Neighbours<MessageOrigin>>: Encode,
impl<MessageOrigin> Encode for BookState<MessageOrigin>where Option<Neighbours<MessageOrigin>>: Encode,
sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy )
Convert self to a slice and append it to the destination.
sourcefn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
sourceimpl<MessageOrigin> MaxEncodedLen for BookState<MessageOrigin>where
Option<Neighbours<MessageOrigin>>: MaxEncodedLen,
impl<MessageOrigin> MaxEncodedLen for BookState<MessageOrigin>where Option<Neighbours<MessageOrigin>>: MaxEncodedLen,
sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.